@@ -4,12 +4,12 @@
 ##
 ## Copyright, contact and other information can be found
 ## at the bottom of this file, or by going to:
-## http://search.cpan.org/dist/Devel-NYTProf/
+## http://metacpan.org/release/Devel-NYTProf/
 ##
 ###########################################################
 package Devel::NYTProf;
 
-our $VERSION = '6.01'; # also change in Devel::NYTProf::Core
+our $VERSION = '6.07'; # also change in Devel::NYTProf::Core
 
 package    # hide the package from the PAUSE indexer
     DB;
@@ -36,7 +36,8 @@ if ($use_db_sub) {                     # install DB::DB sub
 # DB::sub shouldn't be called, but needs to exist for perl <5.8.7 (<perl@24265)
 # Could be called in obscure cases, e.g. if "perl -d" (not -d:NYTProf)
 # was used with Devel::NYTProf loaded some other way
-sub sub { die "DB::sub called unexpectedly" }
+*sub = sub { warn "DB::sub called unexpectedly (@{[ caller(0) ]})" }
+  if $] < 5.008008;
 
 sub CLONE { DB::disable_profiler }
 
@@ -64,7 +65,7 @@ Devel::NYTProf - Powerful fast feature-rich Perl source code profiler
 
 I give talks on profiling perl code, including a detailed look at how to use
 NYTProf and how to optimize your code, every year. A video of my YAPC::NA 2014
-talk can be found at L<http://perltv.org/v/performance-profiling-with-develnytprof>
+talk can be found at L<https://youtu.be/T7EK6RZAnEA>
 
 
 =head1 DESCRIPTION
@@ -277,7 +278,7 @@ Usually you'd load Devel::NYTProf on the command line using the perl -d option:
 
   perl -d:NYTProf some_perl.pl
 
-To save typing the ':NYTProf' you could set the PERL5DB env var 
+To save typing the ':NYTProf' you could set the L<C<PERL5DB> environment variable|perlrun/PERL5DB>:
 
   PERL5DB='use Devel::NYTProf'
 
@@ -285,7 +286,7 @@ and then just perl -d would work:
 
   perl -d some_perl.pl
 
-Or you can avoid the need to add the -d option at all by using the C<PERL5OPT> env var:
+Or you can avoid the need to add the -d option at all by using the L<C<PERL5OPT>> environment variable|perlrun/PERL5OPT>:
 
   PERL5OPT=-d:NYTProf
 
@@ -332,7 +333,7 @@ Specify the name of the file that L</trace=N> output should be written to.
 Specify at which phase of program execution the profiler should be enabled:
 
   start=begin - start immediately (the default)
-  start=init  - start at beginning of INIT phase (after compilation)
+  start=init  - start at beginning of INIT phase (after compilation/use/BEGIN)
   start=end   - start at beginning of END phase
   start=no    - don't automatically start
 
@@ -340,6 +341,9 @@ The start=no option is handy if you want to explicitly control profiling
 by calling DB::enable_profile() and DB::disable_profile() yourself.
 See L</RUN-TIME CONTROL OF PROFILING>.
 
+The start=init option is handy if you want to avoid profiling the loading and
+initialization of modules.
+
 =head2 optimize=0
 
 Disable the perl optimizer.
@@ -820,9 +824,9 @@ If you don't need statement-level profiling then you can disable it via L</stmts
 To further boost statement-level profiling performance try L</leave=0> but note that
 I<will> apportion timings for some kinds of statements less accurate).
 
-If you don't need call stacks or flamegraph then disable it via L</calls=0>.
+If you don't need call stacks or flamegraph then disable it via L<calls=0|/calls=N>.
 If you don't need subroutine profiling then you can disable it via L</subs=0>.
-If you do need it but don't need timings for perl opcodes then set L</slowops=0>.
+If you do need it but don't need timings for perl opcodes then set L<slowops=0|/slowops=N>.
 
 Generally speaking, setting calls=0 and slowops=0 will give you a useful boost
 with the least loss of detail.
@@ -853,7 +857,7 @@ This is the main report generation tool for NYTProf.
 =head2 nytprofcg
 
 Translates a profile into a format that can be loaded into KCachegrind
-L<http://kcachegrind.sourceforge.net>
+L<http://kcachegrind.github.io/>
 
 =head2 nytprofcalls
 
@@ -1140,7 +1144,7 @@ Mailing list and discussion at L<http://groups.google.com/group/develnytprof-dev
 
 Blog posts L<http://blog.timbunce.org/tag/nytprof/>
 
-Public SVN Repository and hacking instructions at L<http://code.google.com/p/perl-devel-nytprof/>
+Public Github Repository and hacking instructions at L<https://github.com/timbunce/devel-nytprof/>
 
 L<nytprofhtml> is a script included that produces html reports.
 L<nytprofcsv> is another script included that produces plain text CSV reports.
@@ -1158,9 +1162,10 @@ DTrace L<https://speakerdeck.com/mrallen1/perl-dtrace-and-you>
 
 =head1 TROUBLESHOOTING
 
-=head2 "Profile data incomplete, ..." or "File format error: ..."
+=head2 "Profile data incomplete, ..." or "Profile format error: ..."
 
-This error message means the file doesn't contain all the expected data.
+This error message means the file doesn't contain all the expected data
+or the data has been corrupted in some way.
 That may be because it was truncated (perhaps the filesystem was full) or,
 more commonly, because the all the expected data hasn't been written.
 
@@ -1171,8 +1176,10 @@ If the process being profiled is still running you'll need to wait until it
 exits cleanly (runs C<END> blocks or L</finish_profile> is called explicitly).
 
 If the process being profiled has exited then it's likely that it met with a
-sudden and unnatural death that didn't give NYTProf a chance to finish the profile.
-If the sudden death was due to a signal then L</sigexit=1> may help.
+sudden and unnatural death that didn't give NYTProf a chance to finish the
+profile.  If the sudden death was due to a signal, like SIGTERM, or a SIGINT
+from pressing Ctrl-C, then the L</sigexit=1> option may help.
+
 If the sudden death was due to calling C<POSIX::_exit($status)> then you'll
 need to call L</finish_profile> before calling C<POSIX::_exit>.
 
@@ -1180,6 +1187,11 @@ You'll also get this error if the code trying to read the profile is itself
 being profiled. That's most likely to happen if you enable profiling via the
 C<PERL5OPT> environment variable and have forgotten to unset it.
 
+If you've encountered this error message, and you're sure you've understood the
+concerns described above, and you're sure they don't apply in your case, then
+please open an issue.  Be sure to include sufficient information so I can see
+how you've addressed these likely causes.
+
 =head2 Some source files don't have profile information
 
 This is usually due to NYTProf being initialized after some perl files have
@@ -1195,7 +1207,7 @@ You could also try using the L</use_db_sub=1> option.
 When using the statement profiler you may see a warning message like this:
 
   Eval '(eval 2)' (fid 9, flags:viastmt,savesrc) has unknown invoking fid 10
- 
+
 Notice that the eval file id (fid 9 in this case) is lower than the file id
 that invoked the eval (fid 10 in this case). This is a known problem caused by
 the way perl works and how the profiler assigns and outputs the file ids.
@@ -1251,31 +1263,16 @@ Other contributors are noted in the Changes file.
 
 Many thanks to B<Adam Kaplan> who created C<NYTProf> initially by forking
 C<Devel::FastProf> adding reporting from C<Devel::Cover> and a test suite.
-For more details see L</HISTORY> below.
 
 =head1 COPYRIGHT AND LICENSE
 
   Copyright (C) 2008 by Adam Kaplan and The New York Times Company.
-  Copyright (C) 2008-2013 by Tim Bunce, Ireland.
+  Copyright (C) 2008-2016 by Tim Bunce, Ireland.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
-=head1 HISTORY
-
-A bit of history (and a shameless plug from Adam)...
-
-NYTProf stands for 'New York Times Profiler'. Indeed, this module was initially
-developed from Devel::FastProf by The New York Times Co. to help our developers
-quickly identify bottlenecks in large Perl applications.  The NY Times loves
-Perl and we hope the community will benefit from our work as much as we have
-from theirs.
-
-Please visit L<http://open.nytimes.com>, our open source blog to see what we
-are up to, L<http://code.nytimes.com> to see some of our open projects and then
-check out L<http://nytimes.com> for the latest news!
-
 =head2 Background
 
 Subroutine-level profilers:
